@@ -41,8 +41,8 @@ enum {
 enum {
     ATTR_UNKNOWN = 0,
     ATTR_CLIP_PATH,
-    ATTR_CLIP_RULE,
     ATTR_CLIP_PATH_UNITS,
+    ATTR_CLIP_RULE,
     ATTR_COLOR,
     ATTR_CX,
     ATTR_CY,
@@ -56,6 +56,7 @@ enum {
     ATTR_GRADIENT_TRANSFORM,
     ATTR_GRADIENT_UNITS,
     ATTR_HEIGHT,
+    ATTR_HREF,
     ATTR_ID,
     ATTR_OFFSET,
     ATTR_OPACITY,
@@ -83,15 +84,14 @@ enum {
     ATTR_X,
     ATTR_X1,
     ATTR_X2,
-    ATTR_XLINK_HREF,
     ATTR_Y,
     ATTR_Y1,
     ATTR_Y2
 };
 
-#define MAX_NAME 20
+#define MAX_NAME 19
 typedef struct {
-    char name[MAX_NAME];
+    const char* name;
     int id;
 } name_entry_t;
 
@@ -161,6 +161,7 @@ static int attributeid(const char* data, size_t length)
         {"gradientTransform", ATTR_GRADIENT_TRANSFORM},
         {"gradientUnits", ATTR_GRADIENT_UNITS},
         {"height", ATTR_HEIGHT},
+        {"href", ATTR_HREF},
         {"id", ATTR_ID},
         {"offset", ATTR_OFFSET},
         {"opacity", ATTR_OPACITY},
@@ -188,7 +189,7 @@ static int attributeid(const char* data, size_t length)
         {"x", ATTR_X},
         {"x1", ATTR_X1},
         {"x2", ATTR_X2},
-        {"xlink:href", ATTR_XLINK_HREF},
+        {"xlink:href", ATTR_HREF},
         {"y", ATTR_Y},
         {"y1", ATTR_Y1},
         {"y2", ATTR_Y2}
@@ -314,7 +315,7 @@ static hashmap_t* hashmap_create(void)
 static size_t hashmap_hash(const char* data, size_t length)
 {
     size_t h = length;
-    for(int i = 0; i < length; i++) {
+    for(size_t i = 0; i < length; i++) {
         h = h * 31 + *data;
         ++data;
     }
@@ -327,7 +328,7 @@ static bool hashmap_eq(const hashmap_entry_t* entry, const char* data, size_t le
     const string_t* name = &entry->name;
     if(name->length != length)
         return false;
-    for(int i = 0; i < length; i++) {
+    for(size_t i = 0; i < length; i++) {
         if(data[i] != name->data[i]) {
             return false;
         }
@@ -341,7 +342,7 @@ static void hashmap_expand(hashmap_t* map)
     if(map->size > (map->capacity * 3 / 4)) {
         size_t newcapacity = map->capacity << 1;
         hashmap_entry_t** newbuckets = calloc(newcapacity, sizeof(hashmap_entry_t*));
-        for(int i = 0; i < map->capacity; i++) {
+        for(size_t i = 0; i < map->capacity; i++) {
             hashmap_entry_t* entry = map->buckets[i];
             while(entry) {
                 hashmap_entry_t* next = entry->next;
@@ -1609,7 +1610,7 @@ static element_t* find_element(const plutosvg_document_t* document, const string
 
 static element_t* resolve_href(const plutosvg_document_t* document, const element_t* element)
 {
-    const string_t* value = find_attribute(element, ATTR_XLINK_HREF, false);
+    const string_t* value = find_attribute(element, ATTR_HREF, false);
     if(value && value->length > 1 && value->data[0] == '#') {
         string_t id = {value->data + 1, value->length - 1};
         return find_element(document, &id);
@@ -2412,7 +2413,7 @@ static void transform_view_rect(const view_position_t* position, plutovg_rect_t*
 
 static plutovg_surface_t* load_image(const element_t* element)
 {
-    const string_t* value = find_attribute(element, ATTR_XLINK_HREF, false);
+    const string_t* value = find_attribute(element, ATTR_HREF, false);
     if(value == NULL)
         return false;
     const char* it = value->data;
